@@ -4,226 +4,217 @@
 <context>
     <name>MainWindow</name>
     <message>
-        <location filename="../mainwindow.ui" line="20"/>
+        <location filename="../src/gui/mainwindow.ui" line="20"/>
         <source>MX Boot Repair</source>
         <translation>MX Boot-reparatie</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="45"/>
+        <location filename="../src/gui/mainwindow.ui" line="45"/>
         <source>MX Boot Repair is a utility that can be used to reinstall GRUB bootloader on the ESP (EFI System Partition), MBR (Master Boot Record) or root partition. It provides the option to reconstruct the GRUB configuration file and to back up and restore MBR or PBR (root).</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="64"/>
+        <location filename="../src/gui/mainwindow.ui" line="64"/>
         <source>What would you like to do?</source>
         <translation>Wat wilt u doen?</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="94"/>
+        <location filename="../src/gui/mainwindow.ui" line="94"/>
         <source>Backup MBR or PBR (legacy boot only)</source>
         <translation>Backup MBR of PBR (enkel legacy boot)</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="70"/>
+        <location filename="../src/gui/mainwindow.ui" line="70"/>
         <source>Reinstall GRUB bootloader on ESP, MBR or PBR (root)</source>
         <translation>Herinstalleer GRUB bootlader in ESP, MBR of PBR (root)</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="80"/>
+        <location filename="../src/gui/mainwindow.ui" line="80"/>
         <source>Repair GRUB configuration file</source>
         <translation>Herstel GRUB configuratiebestand</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="87"/>
+        <location filename="../src/gui/mainwindow.ui" line="87"/>
         <source>Regenerate initramfs images</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="101"/>
+        <location filename="../src/gui/mainwindow.ui" line="101"/>
         <source>Restore MBR or PBR from backup (legacy boot only)</source>
         <translation>Herstel MBR of PBR van backup (enkel legacy boot)</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="134"/>
-        <location filename="../mainwindow.cpp" line="591"/>
+        <location filename="../src/gui/mainwindow.ui" line="134"/>
+        <location filename="../src/gui/mainwindow.cpp" line="419"/>
         <source>Select Boot Method</source>
         <translation>Selecteer Bootmethode</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="152"/>
+        <location filename="../src/gui/mainwindow.ui" line="152"/>
         <source>Master Boot Record</source>
         <translation>Master Boot Record</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="155"/>
+        <location filename="../src/gui/mainwindow.ui" line="155"/>
         <source>MBR</source>
         <translation>MBR</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="158"/>
-        <location filename="../mainwindow.ui" line="398"/>
+        <location filename="../src/gui/mainwindow.ui" line="158"/>
+        <location filename="../src/gui/mainwindow.ui" line="398"/>
         <source>Alt+B</source>
         <translation>Alt+B</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="193"/>
-        <location filename="../mainwindow.cpp" line="592"/>
+        <location filename="../src/gui/mainwindow.ui" line="193"/>
+        <location filename="../src/gui/mainwindow.cpp" line="420"/>
         <source>Location:</source>
         <translation>Locatie:</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="218"/>
+        <location filename="../src/gui/mainwindow.ui" line="218"/>
         <source>EFI System Partition</source>
         <translation>EFI Systeempartitie</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="221"/>
+        <location filename="../src/gui/mainwindow.ui" line="221"/>
         <source>ESP</source>
         <translation>ESP</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="240"/>
+        <location filename="../src/gui/mainwindow.ui" line="240"/>
         <source>Root (Partition Boot Record)</source>
         <translation>Root (Partition Boot Record - PBR)</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="243"/>
-        <location filename="../mainwindow.cpp" line="594"/>
+        <location filename="../src/gui/mainwindow.ui" line="243"/>
+        <location filename="../src/gui/mainwindow.cpp" line="422"/>
         <source>root</source>
         <translation>root</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="278"/>
-        <location filename="../mainwindow.cpp" line="599"/>
+        <location filename="../src/gui/mainwindow.ui" line="278"/>
+        <location filename="../src/gui/mainwindow.cpp" line="427"/>
         <source>Select root location:</source>
         <translation>Selecteer root locatie:</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="300"/>
-        <location filename="../mainwindow.cpp" line="593"/>
+        <location filename="../src/gui/mainwindow.ui" line="300"/>
+        <location filename="../src/gui/mainwindow.cpp" line="421"/>
         <source>Install on:</source>
         <translation>Installeer op</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="389"/>
+        <location filename="../src/gui/mainwindow.ui" line="389"/>
         <source>About this application</source>
         <translation>Over deze applicatie</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="392"/>
+        <location filename="../src/gui/mainwindow.ui" line="392"/>
         <source>About...</source>
         <translation>Over...</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="440"/>
+        <location filename="../src/gui/mainwindow.ui" line="440"/>
         <source>Display help </source>
         <translation>Toon help</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="443"/>
+        <location filename="../src/gui/mainwindow.ui" line="443"/>
         <source>Help</source>
         <translation>Help</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="449"/>
+        <location filename="../src/gui/mainwindow.ui" line="449"/>
         <source>Alt+H</source>
         <translation>Alt+H</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="490"/>
+        <location filename="../src/gui/mainwindow.ui" line="490"/>
         <source>Cancel any changes then quit</source>
         <translation>Iedere verandering ongedaan maken, dan afsluiten</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="493"/>
+        <location filename="../src/gui/mainwindow.ui" line="493"/>
         <source>Cancel</source>
         <translation>Cancel</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="499"/>
+        <location filename="../src/gui/mainwindow.ui" line="499"/>
         <source>Alt+N</source>
         <translation>Alt+N</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="518"/>
+        <location filename="../src/gui/mainwindow.ui" line="518"/>
         <source>Apply any changes</source>
         <translation>Veranderingen toepassen</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="521"/>
-        <location filename="../mainwindow.cpp" line="79"/>
+        <location filename="../src/gui/mainwindow.ui" line="521"/>
+        <location filename="../src/gui/mainwindow.cpp" line="78"/>
         <source>Next</source>
-        <translation type="unfinished"></translation>
+        <translation>Volgende</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="627"/>
+        <location filename="../src/gui/mainwindow.cpp" line="455"/>
         <source>Apply</source>
         <translation>Toepassen</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="94"/>
+        <location filename="../src/gui/mainwindow.cpp" line="98"/>
         <source>GRUB is being installed on %1 device.</source>
         <translation>Grub wordt geïnstalleerd op apparaat %1.</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="133"/>
-        <location filename="../mainwindow.cpp" line="216"/>
-        <location filename="../mainwindow.cpp" line="271"/>
-        <location filename="../mainwindow.cpp" line="389"/>
-        <location filename="../mainwindow.cpp" line="481"/>
-        <location filename="../mainwindow.cpp" line="519"/>
-        <location filename="../mainwindow.cpp" line="632"/>
-        <location filename="../mainwindow.cpp" line="636"/>
-        <location filename="../mainwindow.cpp" line="643"/>
-        <location filename="../mainwindow.cpp" line="649"/>
-        <location filename="../mainwindow.cpp" line="657"/>
-        <location filename="../mainwindow.cpp" line="664"/>
-        <location filename="../mainwindow.cpp" line="716"/>
-        <location filename="../mainwindow.cpp" line="727"/>
+        <location filename="../src/gui/mainwindow.cpp" line="286"/>
+        <location filename="../src/gui/mainwindow.cpp" line="344"/>
+        <location filename="../src/gui/mainwindow.cpp" line="460"/>
+        <location filename="../src/gui/mainwindow.cpp" line="464"/>
+        <location filename="../src/gui/mainwindow.cpp" line="471"/>
+        <location filename="../src/gui/mainwindow.cpp" line="477"/>
+        <location filename="../src/gui/mainwindow.cpp" line="485"/>
+        <location filename="../src/gui/mainwindow.cpp" line="492"/>
         <source>Error</source>
         <translation>Foutmelding</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="134"/>
-        <location filename="../mainwindow.cpp" line="217"/>
-        <location filename="../mainwindow.cpp" line="272"/>
         <source>Could not set up chroot environment.
 Please double-check the selected location.</source>
-        <translation>Kan de chroot omgeving niet opzetten.
+        <translation type="vanished">Kan de chroot omgeving niet opzetten.
 Controleer alstublieft de geselecteerde locatie.</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="197"/>
+        <location filename="../src/gui/mainwindow.cpp" line="136"/>
         <source>The GRUB configuration file (grub.cfg) is being rebuilt.</source>
         <translation>Het GRUB configuratiebestand (grub.cfg) wordt opnieuw gebouwd.</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="233"/>
+        <location filename="../src/gui/mainwindow.cpp" line="170"/>
         <source>Generating initramfs images on: %1</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="285"/>
+        <location filename="../src/gui/mainwindow.cpp" line="199"/>
         <source>Backing up MBR or PBR from %1 device.</source>
         <translation>Backup maken van MBR of PBR van apparaat %1 .</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="361"/>
+        <location filename="../src/gui/mainwindow.cpp" line="255"/>
         <source>Warning</source>
         <translation>Waarschuwing</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="362"/>
+        <location filename="../src/gui/mainwindow.cpp" line="256"/>
         <source>You are going to write the content of </source>
         <translation>U gaat de inhoud beschrijven van</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="362"/>
+        <location filename="../src/gui/mainwindow.cpp" line="256"/>
         <source> to </source>
         <translation>naar</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="363"/>
+        <location filename="../src/gui/mainwindow.cpp" line="257"/>
         <source>
 
 Are you sure?</source>
@@ -232,176 +223,331 @@ Are you sure?</source>
 Weet u het zeker?</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="369"/>
+        <location filename="../src/gui/mainwindow.cpp" line="263"/>
         <source>Restoring MBR/PBR from backup to %1 device.</source>
         <translation>Herstellen MBR of PBR van backup naar %1 apparaat.</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="390"/>
+        <location filename="../src/gui/mainwindow.cpp" line="287"/>
         <source>Could not find EFI system partition (ESP) on any system disks. Please create an ESP and try again.</source>
         <translation>Kon EFI systeempartitie (ESP) niet vinden op geen enkele systeem schijf. Creëer aub een ESP en probeer opnieuw.</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="433"/>
+        <location filename="../src/gui/mainwindow.cpp" line="299"/>
         <source>Select %1 location:</source>
         <translation>Selecteer %1 locatie:</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="458"/>
+        <location filename="../src/gui/mainwindow.cpp" line="322"/>
         <source>Back</source>
         <translation>Terug</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="475"/>
+        <location filename="../src/gui/mainwindow.cpp" line="338"/>
         <source>Success</source>
         <translation>Gelukt</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="475"/>
+        <location filename="../src/gui/mainwindow.cpp" line="338"/>
         <source>Process finished with success.&lt;p&gt;&lt;b&gt;Do you want to exit MX Boot Repair?&lt;/b&gt;</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="481"/>
+        <location filename="../src/gui/mainwindow.cpp" line="344"/>
         <source>Process finished. Errors have occurred.</source>
         <translation>Proces beëindigd. Er zijn fouten opgetreden.</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="508"/>
+        <location filename="../src/gui/mainwindow.cpp" line="105"/>
+        <location filename="../src/gui/mainwindow.cpp" line="144"/>
+        <location filename="../src/gui/mainwindow.cpp" line="176"/>
         <source>Enter password to unlock %1 encrypted partition:</source>
         <translation>Voer wachtwoord in om versleutelde partitie %1 te ontgrendelen:</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="519"/>
         <source>Sorry, could not open %1 LUKS container</source>
-        <translation>Sorry, kon %1 LUKS container niet openen</translation>
+        <translation type="vanished">Sorry, kon %1 LUKS container niet openen</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="598"/>
+        <location filename="../src/gui/mainwindow.cpp" line="426"/>
         <source>Select GRUB location</source>
         <translation>Selecteer GRUB locatie</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="607"/>
+        <location filename="../src/gui/mainwindow.cpp" line="435"/>
         <source>Select initramfs options</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="617"/>
+        <location filename="../src/gui/mainwindow.cpp" line="445"/>
         <source>Select Item to Back Up</source>
         <translation>Selecteer Item om te Backuppen</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="622"/>
+        <location filename="../src/gui/mainwindow.cpp" line="450"/>
         <source>Select Item to Restore</source>
         <translation>Selecteer Item om te Herstellen</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="632"/>
-        <location filename="../mainwindow.cpp" line="643"/>
+        <location filename="../src/gui/mainwindow.cpp" line="460"/>
+        <location filename="../src/gui/mainwindow.cpp" line="471"/>
         <source>No location was selected.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="637"/>
-        <location filename="../mainwindow.cpp" line="650"/>
+        <location filename="../src/gui/mainwindow.cpp" line="465"/>
+        <location filename="../src/gui/mainwindow.cpp" line="478"/>
         <source>Please select the root partition of the system you want to fix.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="655"/>
+        <location filename="../src/gui/mainwindow.cpp" line="483"/>
         <source>Select backup file name</source>
         <translation>Selecteer backup bestandsnaam</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="657"/>
-        <location filename="../mainwindow.cpp" line="664"/>
+        <location filename="../src/gui/mainwindow.cpp" line="485"/>
+        <location filename="../src/gui/mainwindow.cpp" line="492"/>
         <source>No file was selected.</source>
         <translation>Er was geen bestand geselecteerd.</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="662"/>
+        <location filename="../src/gui/mainwindow.cpp" line="490"/>
         <source>Select MBR or PBR backup file</source>
         <translation>Selecteer MBR of PBR backupbestand</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="680"/>
+        <location filename="../src/gui/mainwindow.cpp" line="508"/>
         <source>About %1</source>
         <translation>Over %1</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="682"/>
+        <location filename="../src/gui/mainwindow.cpp" line="510"/>
         <source>Version: </source>
         <translation>Versie:</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="683"/>
+        <location filename="../src/gui/mainwindow.cpp" line="511"/>
         <source>Simple boot repair program for MX Linux</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="685"/>
+        <location filename="../src/gui/mainwindow.cpp" line="513"/>
         <source>Copyright (c) MX Linux</source>
         <translation>Copyright (c) MX Linux</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="686"/>
+        <location filename="../src/gui/mainwindow.cpp" line="514"/>
         <source>%1 License</source>
         <translation>%1 Licentie</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="699"/>
+        <location filename="../src/gui/mainwindow.cpp" line="527"/>
         <source>%1 Help</source>
         <translation>%1 Help</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="716"/>
         <source>Sorry, could not mount %1 partition</source>
-        <translation>Sorry, kon partitie %1 niet aankoppelen</translation>
+        <translation type="vanished">Sorry, kon partitie %1 niet aankoppelen</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="727"/>
         <source>Could not create a temporary folder</source>
-        <translation>Kon tijdelijke folder niet creëren</translation>
+        <translation type="vanished">Kon tijdelijke folder niet creëren</translation>
     </message>
 </context>
 <context>
     <name>QObject</name>
     <message>
-        <location filename="../about.cpp" line="52"/>
+        <location filename="../src/gui/about.cpp" line="52"/>
         <source>License</source>
         <translation>Licentie</translation>
     </message>
     <message>
-        <location filename="../about.cpp" line="53"/>
-        <location filename="../about.cpp" line="63"/>
+        <location filename="../src/gui/about.cpp" line="53"/>
+        <location filename="../src/gui/about.cpp" line="63"/>
         <source>Changelog</source>
         <translation>Changelog</translation>
     </message>
     <message>
-        <location filename="../about.cpp" line="54"/>
+        <location filename="../src/gui/about.cpp" line="54"/>
         <source>Cancel</source>
         <translation>Cancel</translation>
     </message>
     <message>
-        <location filename="../about.cpp" line="73"/>
+        <location filename="../src/gui/about.cpp" line="73"/>
         <source>&amp;Close</source>
         <translation>&amp;Sluiten</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="53"/>
+        <location filename="../src/gui/main.cpp" line="74"/>
         <source>MX Boot Repair</source>
         <translation>MX Boot-reparatie</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="86"/>
+        <location filename="../src/gui/main.cpp" line="82"/>
         <source>Error</source>
         <translation>Foutmelding</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="87"/>
+        <location filename="../src/gui/main.cpp" line="83"/>
         <source>You must run this program with admin access.</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="../src/cli/controller.cpp" line="29"/>
+        <source>Invalid index. Try again: </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/cli/controller.cpp" line="48"/>
+        <source>Invalid selection. Enter a number </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/cli/controller.cpp" line="157"/>
+        <source>MX Boot Repair (CLI)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/cli/controller.cpp" line="158"/>
+        <source>1) Install GRUB</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/cli/controller.cpp" line="159"/>
+        <source>2) Repair GRUB (update-grub)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/cli/controller.cpp" line="160"/>
+        <source>3) Regenerate initramfs</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/cli/controller.cpp" line="161"/>
+        <source>4) Backup MBR/PBR</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/cli/controller.cpp" line="162"/>
+        <source>5) Restore MBR/PBR</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/cli/controller.cpp" line="163"/>
+        <source>q) Quit</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/cli/controller.cpp" line="164"/>
+        <source>Select action [1-5 or &apos;q&apos; to quit]: </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/cli/controller.cpp" line="170"/>
+        <source>Invalid selection. Enter 1-5 or &apos;q&apos; to quit.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/cli/controller.cpp" line="175"/>
+        <source>Target: 0) MBR  1) ESP  2) Root</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/cli/controller.cpp" line="176"/>
+        <source>Select target</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/cli/controller.cpp" line="182"/>
+        <location filename="../src/cli/controller.cpp" line="217"/>
+        <location filename="../src/cli/controller.cpp" line="230"/>
+        <source>No partitions found. Returning to main menu.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/cli/controller.cpp" line="186"/>
+        <location filename="../src/cli/controller.cpp" line="243"/>
+        <location filename="../src/cli/controller.cpp" line="261"/>
+        <source>No disks found. Returning to main menu.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/cli/controller.cpp" line="191"/>
+        <source>Select disk for MBR (e.g., sda)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/cli/controller.cpp" line="195"/>
+        <source>Select partition for GRUB (e.g., sda1)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/cli/controller.cpp" line="200"/>
+        <source>Select root partition of installed system</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/cli/controller.cpp" line="218"/>
+        <source>Select root partition to repair</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/cli/controller.cpp" line="231"/>
+        <source>Select root partition to regenerate initramfs</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/cli/controller.cpp" line="244"/>
+        <source>Select disk to back up MBR/PBR from</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/cli/controller.cpp" line="247"/>
+        <source>Output file path (or &apos;b&apos; to go back, &apos;q&apos; to quit): </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/cli/controller.cpp" line="262"/>
+        <source>Select disk to restore MBR/PBR to</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/cli/controller.cpp" line="265"/>
+        <source>Input backup file path (or &apos;b&apos; to go back, &apos;q&apos; to quit): </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/cli/controller.cpp" line="272"/>
+        <source>WARNING: This will overwrite the first 446 bytes of /dev/</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/cli/controller.cpp" line="272"/>
+        <source>. Continue? [y/N]: </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/cli/controller.cpp" line="275"/>
+        <source>yes</source>
+        <comment>confirmation input: full word</comment>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/cli/controller.cpp" line="276"/>
+        <source>y</source>
+        <comment>confirmation input: single-letter yes</comment>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/cli/controller.cpp" line="280"/>
+        <source>Cancelled.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/cli/controller.cpp" line="287"/>
+        <source>Unknown selection</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
